require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmadministrativeuser',
  dscmeta_resource_friendly_name: 'CMAdministrativeUser',
  dscmeta_resource_name: 'DSC_CMAdministrativeUser',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMAdministrativeUser resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_collectionstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names for the collections desired to be removed from an administrative user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_scopes: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names for the scopes desired to be assigned to an administrative user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_collectionstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names for the collections desired to be added to an administrative user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_rolestoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names for the roles desired to be added to an administrative user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the administrative user is present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_rolestoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names for the roles desired to be removed from an administrative user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_scopestoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names for the scopes desired to be removed from an administrative user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_scopestoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names for the scopes desired to be added to an administrative user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_collections: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names for the collections desired to be assigned to an administrative user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_adminname: {
      type: 'String',
      desc: 'Specifies the name of the administrator account.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_roles: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names for the roles desired to be assigned to an administrative user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
