require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmassetintelligencepoint',
  dscmeta_resource_friendly_name: 'CMAssetIntelligencePoint',
  dscmeta_resource_name: 'DSC_CMAssetIntelligencePoint',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMAssetIntelligencePoint resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_start: {
      type: 'Optional[String]',
      desc: 'Specifies the start date and start time for the synchronization schedule Month/Day/Year, example 1/1/2020 02:00.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablesynchronization: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to synchronize the asset intelligence catalog.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dayofmonth: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the day number for MonthlyByDay schedules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enable: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the installed asset intelligence role is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_monthlyweekorder: {
      type: "Optional[Enum['First', 'first', 'Second', 'second', 'Third', 'third', 'Fourth', 'fourth', 'Last', 'last']]",
      desc: 'Specifies week order for MonthlyByWeek schedule type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_dayofweek: {
      type: "Optional[Enum['Sunday', 'sunday', 'Monday', 'monday', 'Tuesday', 'tuesday', 'Wednesday', 'wednesday', 'Thursday', 'thursday', 'Friday', 'friday', 'Saturday', 'saturday']]",
      desc: 'Specifies the day of week name for MonthlyByWeek and Weekly schedules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scheduletype: {
      type: "Optional[Enum['MonthlyByDay', 'monthlybyday', 'MonthlyByWeek', 'monthlybyweek', 'Weekly', 'weekly', 'Days', 'days', 'None', 'none']]",
      desc: 'Specifies the schedule type for the synchronization schedule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the asset intelligence synchronization point is present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_removecertificate: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to remove a configured certificate file. Mutually exclusive with the CertificateFile Parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_siteservername: {
      type: 'Optional[String]',
      desc: 'Specifies the Site Server to install or configure the role on. If the role is already installed on another server this setting will be ignored.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recurinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how often the ScheduleType is run.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes', 'yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'.",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatefile: {
      type: 'Optional[String]',
      desc: 'Specifies the path to a System Center Online authentication certificate (.pfx) file. If used, this must be in UNC format. Local paths are not allowed. Mutually exclusive with the RemoveCertificate parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
