require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmboundarygroups',
  dscmeta_resource_friendly_name: 'CMBoundaryGroups',
  dscmeta_resource_name: 'DSC_CMBoundaryGroups',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMBoundaryGroups resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_sitesystems: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of SiteSystems to match on the Boundary Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_boundaryaction: {
      type: "Optional[Enum['Match', 'match', 'Add', 'add', 'Remove', 'remove']]",
      desc: 'Specifies the Boundaries are to match, add, or remove Boundaries from the Boundary Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_securityscopes: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Security Scopes to match to the Boundary Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_securityscopestoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Security Scopes to add to the Boundary Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the Boundary Group is present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityscopestoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Security Scopes to remove from the Boundary Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_boundarygroup: {
      type: 'String',
      desc: 'Specifies the name of the Boundary Group.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitesystemstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of SiteSystems to add to the Boundary Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_sitesystemstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of SiteSystems to remove from the Boundary Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_boundaries: {
      type: "Optional[Array[Struct[{
              type => Enum['ADSite', 'adsite', 'IPSubnet', 'ipsubnet', 'IPRange', 'iprange'],
              value => String,
            }]]]",
      desc: 'Specifies an array of Boundaries to add or remove.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DSC_CMBoundaryGroupsBoundaries[]',
      mof_is_embedded: true,
    },
  },
)
