require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmclientpushsettings',
  dscmeta_resource_friendly_name: 'CMClientPushSettings',
  dscmeta_resource_name: 'DSC_CMClientPushSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMClientPushSettings resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_enableautomaticclientpushinstallation: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether Configuration Manager automatically uses client push for discovered computers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_accountstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of accounts to add for use with client push.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_accountstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of accounts to remove for use with client push.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_installclienttodomaincontroller: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to use automatic site-wide client push installation to install the Configuration Manager client software on domain controllers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_installationproperty: {
      type: 'Optional[String]',
      desc: 'Specifies any installation properties to use when installing the Configuration Manager client.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablesystemtypeconfigurationmanager: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether Configuration Manager pushes the client software to Configuration Manager site system servers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_accounts: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of accounts to exactly match for use with client push.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enablesystemtypeserver: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether Configuration Manager pushes the client software to servers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablesystemtypeworkstation: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether Configuration Manager pushes the client software to workstations.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
