require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmclientsettingsclientcache',
  dscmeta_resource_friendly_name: 'CMClientSettingsClientCache',
  dscmeta_resource_name: 'DSC_CMClientSettingsClientCache',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMClientSettingsClientCache resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_configurebranchcache: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if configure branch cache policy is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_configurecachesize: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if client cache size is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_downloadport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the port for content download from peers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_clientsettingname: {
      type: 'String',
      desc: 'Specifies which client settings policy to modify.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxcachesizepercent: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum cache size percentage.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxcachesize: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum cache size by MB.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_clienttype: {
      type: 'Optional[String]',
      desc: 'Specifies the type of client policy setting.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clientsettingstatus: {
      type: 'Optional[String]',
      desc: 'Specifies if the client settings policy exists.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxbranchcachesizepercent: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the percentage of disk size maximum branch cache size.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_broadcastport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the port for initial network broadcast.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enablesuperpeer: {
      type: 'Optional[Boolean]',
      desc: 'Specifies is peer cache source is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablebranchcache: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if branch cache is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
