require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmclientsettingscomputeragent',
  dscmeta_resource_friendly_name: 'CMClientSettingsComputerAgent',
  dscmeta_resource_name: 'DSC_CMClientSettingsComputerAgent',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMClientSettingsComputerAgent resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_enablethirdpartyorchestration: {
      type: "Optional[Enum['No', 'no', 'Yes', 'yes']]",
      desc: 'Specifies if additional software manages the deployment of applications and updates.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interimreminderhr: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies reminder, in hours, for deployment deadlines less than 24 hours.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_finalremindermins: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies reminder, in minutes, for deployment deadlines less than 1 hours.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_displaynewprogramnotification: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if notifications are shown for new deployments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_brandingtitle: {
      type: 'Optional[String]',
      desc: 'Specifies the organizational name displayed in software center.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_initialreminderhr: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies reminder, in hours, for deployment deadlines greater than 24 hours.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_powershellexecutionpolicy: {
      type: "Optional[Enum['AllSigned', 'allsigned', 'Bypass', 'bypass', 'Restricted', 'restricted']]",
      desc: 'Specifies powershell execution policy settings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_useonpremiseshealthattestation: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the on-premises health service is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_clientsettingname: {
      type: 'String',
      desc: 'Specifies which client settings policy to modify.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_suspendbitlocker: {
      type: "Optional[Enum['Never', 'never', 'Always', 'always']]",
      desc: 'Specifies the suspend BitLocker PIN entry on restart.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clienttype: {
      type: 'Optional[String]',
      desc: 'Specifies the type of client policy setting.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_installrestriction: {
      type: "Optional[Enum['AllUsers', 'allusers', 'OnlyAdministrators', 'onlyadministrators', 'OnlyAdministratorsAndPrimaryUsers', 'onlyadministratorsandprimaryusers', 'NoUsers', 'nousers']]",
      desc: 'Specifies the install permissions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablehealthattestation: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if communication with the Health Attestation service is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_usenewsoftwarecenter: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the new software center is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clientsettingstatus: {
      type: 'Optional[String]',
      desc: 'Specifies if the client settings policy exists.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
