require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmclientsettingspower',
  dscmeta_resource_friendly_name: 'CMClientSettingsPower',
  dscmeta_resource_name: 'DSC_CMClientSettingsPower',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMClientSettingsPower resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enable: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if power management plan is to be used.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_clientsettingname: {
      type: 'String',
      desc: 'Specifies which client settings policy to modify.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wakeonlanport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the wake on lan port.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enablewakeupproxy: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the wake up proxy will be enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowusertooptoutfrompowerplan: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if users are allowed to out out from the power plan.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clienttype: {
      type: 'Optional[String]',
      desc: 'Specifies the type of client policy setting.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clientsettingstatus: {
      type: 'Optional[String]',
      desc: 'Specifies if the client settings policy exists.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_firewallexceptionforwakeupproxy: {
      type: "Optional[Array[Enum['None', 'none', 'Domain', 'domain', 'Private', 'private', 'Public', 'public']]]",
      desc: 'Specifies the which firewall states will be configured for wakeup proxy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_wakeupproxyport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the wake up proxy port.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_networkwakeupoption: {
      type: "Optional[Enum['NotConfigured', 'notconfigured', 'Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies if network wake up is not configured, enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wakeupproxydirectaccessprefix: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the IPV6 direct access prefix for the wake up proxy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
