require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmclientsettingsremotetools',
  dscmeta_resource_friendly_name: 'CMClientSettingsRemoteTools',
  dscmeta_resource_name: 'DSC_CMClientSettingsRemoteTools',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMClientSettingsRemoteTools resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_grantpermissiontolocaladministrator: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if remote control permissions are granted to the local administrators group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_remotetoolsstatus: {
      type: 'Optional[String]',
      desc: 'Specifies if the Remote Tools settings is enabled or disabled.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_requireauthentication: {
      type: 'Optional[Boolean]',
      desc: 'Specifies network level required authentication on computers that run Vista or later versions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_manageremotedesktopsetting: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if remote desktop settings are managed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowunattendedcomputer: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if allow remote control of an unattended computer is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_allowclientchange: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if users can change policy or notifications settings in software center.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_permittedviewer: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the permitted viewers for remote control and remote assistance.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_clientsettingname: {
      type: 'String',
      desc: 'Specifies which client settings policy to modify.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_firewallexceptionprofile: {
      type: "Optional[Array[Enum['Domain', 'domain', 'Private', 'private', 'Public', 'public']]]",
      desc: 'Specifies if the firewall exceptions profiles for Remote Tools.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_clienttype: {
      type: 'Optional[String]',
      desc: 'Specifies the type of client policy setting.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_promptuserforclipboardpermission: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if users are prompted for permission to transfer content from share clipboard.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clientsettingstatus: {
      type: 'Optional[String]',
      desc: 'Specifies if the client settings policy exists.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_accesslevel: {
      type: "Optional[Enum['NoAccess', 'noaccess', 'ViewOnly', 'viewonly', 'FullControl', 'fullcontrol']]",
      desc: 'Specifies the access level allowed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_audiblesignal: {
      type: "Optional[Enum['PlayNoSound', 'playnosound', 'PlaySoundAtBeginAndEnd', 'playsoundatbeginandend', 'PlaySoundRepeatedly', 'playsoundrepeatedly']]",
      desc: 'Specifies if sound is played on the client.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_promptuserforpermission: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if users are prompted for remote control permissions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_remoteassistanceaccesslevel: {
      type: "Optional[Enum['None', 'none', 'RemoteViewing', 'remoteviewing', 'FullControl', 'fullcontrol']]",
      desc: 'Specifies the level of access for remote assistance.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_showsessionconnectionbar: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the session connection bar is shown.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_managesolicitedremoteassistance: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if solicited remote assistance settings are managed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_manageunsolicitedremoteassistance: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if unsolicited remote assistance settings are managed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowpermittedviewer: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if permitted viewers are allowed to connect by using remote desktop connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_shownotificationiconontaskbar: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if session notifications are shown on the taskbar.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
