require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmclientsettingssoftwarecenter',
  dscmeta_resource_friendly_name: 'CMClientSettingsSoftwareCenter',
  dscmeta_resource_name: 'DSC_CMClientSettingsSoftwareCenter',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMClientSettingsSoftwareCenter resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_hideinstalledapplication: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if installed applications are hidden.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_hideunapprovedapplication: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if unapproved applications are hidden.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_companyname: {
      type: 'Optional[String]',
      desc: 'Specifies the company name to be used in software center.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_hideapplicationcataloglink: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if application catalog link is hidden.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablecustomize: {
      type: 'Boolean',
      desc: 'Specifies if custom software center is to be used.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableoptionstab: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if options tab is visible.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clientsettingname: {
      type: 'String',
      desc: 'Specifies which client settings policy to modify.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_portaltype: {
      type: 'Optional[String]',
      desc: 'Specifies the portal type selected.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablestatustab: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if status tab is visible.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablecompliancetab: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if compliance tab is visible.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clienttype: {
      type: 'Optional[String]',
      desc: 'Specifies the type of client policy setting.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clientsettingstatus: {
      type: 'Optional[String]',
      desc: 'Specifies if the client settings policy exists.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableapplicationstab: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if application tab is visible.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_colorscheme: {
      type: 'Optional[String]',
      desc: 'Specifies in hex format the color to be used in software center.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableupdatestab: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if updates tab is visible.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableoperatingsystemstab: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if operating system tab is visible.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
