require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmclientsettingssoftwareinventory',
  dscmeta_resource_friendly_name: 'CMClientSettingsSoftwareInventory',
  dscmeta_resource_name: 'DSC_CMClientSettingsSoftwareInventory',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMClientSettingsSoftwareInventory resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_start: {
      type: 'Optional[String]',
      desc: 'Specifies the start date and start time for the software inventory schedule Month/Day/Year, example 1/1/2020 02:00.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dayofmonth: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the day number for MonthlyByDay schedules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enable: {
      type: 'Boolean',
      desc: 'Specifies if software inventory on clients is enabled or disabled.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_monthlyweekorder: {
      type: "Optional[Enum['First', 'first', 'Second', 'second', 'Third', 'third', 'Fourth', 'fourth', 'Last', 'last']]",
      desc: 'Specifies week order for MonthlyByWeek schedule type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_dayofweek: {
      type: "Optional[Enum['Sunday', 'sunday', 'Monday', 'monday', 'Tuesday', 'tuesday', 'Wednesday', 'wednesday', 'Thursday', 'thursday', 'Friday', 'friday', 'Saturday', 'saturday']]",
      desc: 'Specifies the day of week name for MonthlyByWeek and Weekly schedules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scheduletype: {
      type: "Optional[Enum['MonthlyByDay', 'monthlybyday', 'MonthlyByWeek', 'monthlybyweek', 'Weekly', 'weekly', 'Days', 'days', 'Hours', 'hours', 'Minutes', 'minutes', 'None', 'none']]",
      desc: 'Specifies the schedule type for the software inventory schedule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clientsettingname: {
      type: 'String',
      desc: 'Specifies which client settings policy to modify.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_reportoption: {
      type: "Optional[Enum['ProductOnly', 'productonly', 'FileOnly', 'fileonly', 'FullDetail', 'fulldetail']]",
      desc: 'Specify reporting inventory details level.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clienttype: {
      type: 'Optional[String]',
      desc: 'Specifies the type of client policy setting.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clientsettingstatus: {
      type: 'Optional[String]',
      desc: 'Specifies if the client settings policy exists.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recurinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how often the ScheduleType is run.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
