require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmclientstatussettings',
  dscmeta_resource_friendly_name: 'CMClientStatusSettings',
  dscmeta_resource_name: 'DSC_CMClientStatusSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMClientStatusSettings resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_softwareinventorydays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the data collection interval for software inventory client monitoring activities.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_clientpolicydays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the data collection interval for client policy client monitoring activities.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_historycleanupdays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the data collection interval for status history cleanup client monitoring activities.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_heartbeatdiscoverydays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the data collection interval for heartbeat discovery client monitoring activities.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_hardwareinventorydays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the data collection interval for hardware inventory client monitoring activities.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes', 'yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'.",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_statusmessagedays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the data collection interval for status message client monitoring activities.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
