require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmdistributiongroup',
  dscmeta_resource_friendly_name: 'CMDistributionGroup',
  dscmeta_resource_name: 'DSC_CMDistributionGroup',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMDistributionGroup resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityscopestoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Security Scopes to remove from the Distribution Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_collectionstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Collection names to add to the Distribution Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_securityscopes: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Security Scopes to match to the Distribution Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_distributionpointstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Distribution Points to remove from the Distribution Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the Distribution Group is present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_collectionstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Collection names to remove from the Distribution Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_securityscopestoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Security Scopes to add to the Distribution Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_distributionpoints: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Distribution Points to match to the Distribution Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_distributiongroup: {
      type: 'String',
      desc: 'Specifies the Distribution Group name.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_distributionpointstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Distribution Points to add to the Distribution Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_collections: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of Collection names to match to the Distribution Group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
