require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmdistributionpoint',
  dscmeta_resource_friendly_name: 'CMDistributionPoint',
  dscmeta_resource_name: 'DSC_CMDistributionPoint',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMDistributionPoint resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_enableanonymous: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that the distribution point permits anonymous connections from Configuration Manager clients to the content library.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableledbat: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether to adjust the download speed to use the unused network Bandwidth or Windows LEDBAT.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_secondarycontentlibrarylocation: {
      type: 'Optional[String]',
      desc: 'Specifies the secondary content location.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the management point is present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_siteservername: {
      type: 'String',
      desc: 'Specifies the SiteServer to install the role on.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Specifies a description for the distribution point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_primarycontentlibrarylocation: {
      type: 'Optional[String]',
      desc: 'Specifies the primary content location.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clientcommunicationtype: {
      type: "Optional[Enum['Http', 'http', 'Https', 'https']]",
      desc: 'Specifies protocol clients or devices communicate with the distribution point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_minimumfreespacemb: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the amount of free space to reserve on each drive used by this distribution point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_primarypackagesharelocation: {
      type: 'Optional[String]',
      desc: 'Specifies the primary package share location.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_boundarygroupstatus: {
      type: "Optional[Enum['Add', 'add', 'Remove', 'remove', 'Match', 'match']]",
      desc: 'Specifies if the boundary group is to be added, removed, or match BoundaryGroups.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_boundarygroups: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of existing boundary groups by name.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_certificateexpirationtimeutc: {
      type: 'Optional[Timestamp]',
      desc: 'Specifies, in UTC format, the date and time when the certificate expires.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DateTime',
      mof_is_embedded: false,
    },
    dsc_secondarypackagesharelocation: {
      type: 'Optional[String]',
      desc: 'Specifies the secondary package share location.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablebranchcache: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that clients that use Windows BranchCache are allowed to download content from an on-premises distribution point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowprestaging: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the distribution point is enabled for prestaged content.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
