require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmemailnotificationcomponent',
  dscmeta_resource_friendly_name: 'CMEmailNotificationComponent',
  dscmeta_resource_name: 'DSC_CMEmailNotificationComponent',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMEmailNotificationComponent resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enabled: {
      type: 'Boolean',
      desc: 'Specifies if email notifications are enabled or disabled.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_typeofauthentication: {
      type: "Optional[Enum['Anonymous', 'anonymous', 'DefaultServiceAccount', 'defaultserviceaccount', 'Other', 'other']]",
      desc: 'Specifies the method by which Configuration Manager authenticates the site server to the SMTP Server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_port: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the port used to send email.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_smtpserverfqdn: {
      type: 'Optional[String]',
      desc: 'Specifies the FQDN of the site server that will send email.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sendfrom: {
      type: 'Optional[String]',
      desc: 'Specifies the address used to send email.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_username: {
      type: 'Optional[String]',
      desc: 'Specifies the username for authenticating against an SMTP server. Only used when AuthenticationMethod equals Other',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usessl: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to use SSL for email alerts. If omitted, the assumed intent is that SSL is not to be used.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
