require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmfilereplication',
  dscmeta_resource_friendly_name: 'CMFileReplication',
  dscmeta_resource_name: 'DSC_CMFileReplication',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMFileReplication resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_datablocksizekb: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies a data block size, in kilobytes. Used in conjunction with the PulseMode parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_limited: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that bandwidth for a file replication route is limited.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_pulsemode: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that file replication uses data block size and delays between transmissions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_usesystemaccount: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the replication service will use the site system account.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the file replication is present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_filereplicationaccountname: {
      type: 'Optional[String]',
      desc: 'Specifies the account that Configuration Manager uses for file replication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_destinationsitecode: {
      type: 'String',
      desc: 'Specifies the destination site for the file replication route by using a site code.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ratelimitingschedule: {
      type: 'Optional[Array[Struct[{
              limitedbeginhour => Integer[0, 4294967295],
              limitedendhour => Integer[0, 4294967295],
              limitavailablebandwidthpercent => Integer[0, 4294967295],
            }]]]',
      desc: 'Specifies, as an array of CimInstances, hour ranges and bandwidth percentages for limiting file replication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DSC_CMRateLimitingSchedule[]',
      mof_is_embedded: true,
    },
    dsc_networkloadschedule: {
      type: "Optional[Array[Struct[{
              beginhour => Integer[0, 4294967295],
              type => Enum['All', 'all', 'High', 'high', 'MediumHigh', 'mediumhigh', 'Closed', 'closed'],
              endhour => Integer[0, 4294967295],
              day => Enum['Sunday', 'sunday', 'Monday', 'monday', 'Tuesday', 'tuesday', 'Wednesday', 'wednesday', 'Thursday', 'thursday', 'Friday', 'friday', 'Saturday', 'saturday'],
            }]]]",
      desc: 'Specifies, as an array of CimInstances, hour ranges and bandwidth percentages for network load balancing schedule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DSC_CMReplicationNetworkLoadSchedule[]',
      mof_is_embedded: true,
    },
    dsc_delaybetweendatablocksec: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Delay, in seconds, between sending data blocks when PulseMode is used.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_unlimited: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that bandwidth for a file replication route is unlimited.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
