require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmforestdiscovery',
  dscmeta_resource_friendly_name: 'CMForestDiscovery',
  dscmeta_resource_name: 'DSC_CMForestDiscovery',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMForestDiscovery resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_schedulecount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how often the recur interval is run. If hours are specified the max value is 23. Anything over 23 will result in 23 to be set. If days are specified the max value is 31. Anything over 31 will result in 31 to be set.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enabled: {
      type: 'Boolean',
      desc: 'Specifies the enablement of the forest discovery method. If settings is set to $false no other value provided will be evaluated for compliance.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablesubnetboundarycreation: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether Configuration Manager creates IP address range boundaries from AD DS discovery information.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_scheduleinterval: {
      type: "Optional[Enum['Days', 'days', 'Hours', 'hours']]",
      desc: 'Specifies the recur interval of days, hours',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableactivedirectorysiteboundarycreation: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether Configuration Manager creates Active Directory boundaries from AD DS discovery information.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
