require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmgroupdiscovery',
  dscmeta_resource_friendly_name: 'CMGroupDiscovery',
  dscmeta_resource_name: 'DSC_CMGroupDiscovery',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMGroupDiscovery resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_discoverdistributiongroupmembership: {
      type: 'Optional[Boolean]',
      desc: 'Specify if group discovery will discover distribution groups and the members of the group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enablefilteringexpiredpassword: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether Configuration Manager discovers only computers that have updated their computer account password within a specified number of days.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dayofmonth: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the day number for MonthlyByDay schedules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_groupdiscoveryscope: {
      type: 'Optional[Array[Struct[{
              name => String,
              recurse => Boolean,
              ldaplocation => String,
            }]]]',
      desc: 'Specifies an array of Group Discovery Scopes to match to the discovery.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DSC_CMGroupDiscoveryScope[]',
      mof_is_embedded: true,
    },
    dsc_groupdiscoveryscopetoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names of Group Discovery Scopes to exclude to the discovery.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enabledeltadiscovery: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether Configuration Manager discovers resources created or modified in AD DS since the last discovery cycle.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_dayofweek: {
      type: "Optional[Enum['Sunday', 'sunday', 'Monday', 'monday', 'Tuesday', 'tuesday', 'Wednesday', 'wednesday', 'Thursday', 'thursday', 'Friday', 'friday', 'Saturday', 'saturday']]",
      desc: 'Specifies the day of week name for MonthlyByWeek and Weekly schedules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scheduletype: {
      type: "Optional[Enum['MonthlyByDay', 'monthlybyday', 'MonthlyByWeek', 'monthlybyweek', 'Weekly', 'weekly', 'Days', 'days', 'Hours', 'hours', 'Minutes', 'minutes', 'None', 'none']]",
      desc: 'Specifies the schedule type for the group discovery schedule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_start: {
      type: 'Optional[String]',
      desc: 'Specifies the start date and start time for the group discovery schedule Month/Day/Year, example 1/1/2020 02:00.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_groupdiscoveryscopetoinclude: {
      type: 'Optional[Array[Struct[{
              name => String,
              recurse => Boolean,
              ldaplocation => String,
            }]]]',
      desc: 'Specifies an array of Group Discovery Scopes to add to the discovery.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DSC_CMGroupDiscoveryScope[]',
      mof_is_embedded: true,
    },
    dsc_deltadiscoverymins: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of minutes for the delta discovery.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_timesincelastlogondays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specify the number of days for EnableFilteringExpiredLogon.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_monthlyweekorder: {
      type: "Optional[Enum['First', 'first', 'Second', 'second', 'Third', 'third', 'Fourth', 'fourth', 'Last', 'last']]",
      desc: 'Specifies week order for MonthlyByWeek schedule type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recurinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how often the ScheduleType is run.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enablefilteringexpiredlogon: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether Configuration Manager discovers only computers that have logged onto a domain within a specified number of days.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Boolean',
      desc: 'Specifies the enablement of the system discovery method.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_timesincelastpasswordupdatedays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specify the number of days for EnableFilteringExpiredPassword.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
