require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmhierarchysetting',
  dscmeta_resource_friendly_name: 'CMHierarchySetting',
  dscmeta_resource_name: 'DSC_CMHierarchySetting',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMHierarchySetting resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_excludeserver: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that servers are excluded from auto upgrade. Skipped if EnableAutoClientUpgrade is not used.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_preferboundarygroupmanagementpoint: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that the boundary group management point should be preferred.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_targetcollectionname: {
      type: 'Optional[String]',
      desc: 'Target preproduction collection name. Requires use of EnablePreProduction parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableautoclientupgrade: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that automatic client upgrades should be enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_autoupgradedays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Days for Auto-Upgrade advertisement',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_autoresolveclientconflict: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that client conflicts should automatically be resolved.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_approvalmethod: {
      type: "Optional[Enum['AutomaticallyApproveComputersInTrustedDomains', 'automaticallyapprovecomputersintrusteddomains', 'ManuallyApproveEachComputer', 'manuallyapproveeachcomputer', 'AutomaticallyApproveAllComputers', 'automaticallyapproveallcomputers']]",
      desc: 'Approval method to use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fallbacksitecode: {
      type: 'Optional[String]',
      desc: 'Site code of fallback site. Requires use of UseFallbackSite parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableexclusioncollection: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that an exclusion collection should be enabled. Requires use of ExclusionCollectionName parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_usefallbacksite: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that fallback site should be used. Requires use of FallbackSiteCode parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowprestage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that prestaging should be allowed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableprereleasefeature: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that pre-release features should be enabled. This is an operation that cannot be reverted.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exclusioncollectionname: {
      type: 'Optional[String]',
      desc: 'Exclusion collection name. Requires use of EnableExclusionCollection parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_telemetrylevel: {
      type: "Optional[Enum['Basic', 'basic', 'Enhanced', 'enhanced', 'Full', 'full']]",
      desc: 'Level of telemetry to send.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablepreproduction: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that a preproduction collection should be enabled. Requires use of TargetCollectionName parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
