require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cminifile',
  dscmeta_resource_friendly_name: 'CMIniFile',
  dscmeta_resource_name: 'DSC_CMIniFile',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMIniFile resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_joinceip: {
      type: 'Boolean',
      desc: 'Specifies whether to join the Customer Experience Improvement Program (CEIP).',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_rolecommunicationprotocol: {
      type: "Optional[Enum['EnforceHTTPS', 'enforcehttps', 'HTTPorHTTPS', 'httporhttps']]",
      desc: 'Specifies whether to configure all site systems to accept only HTTPS communication from clients, or to configure the communication method for each site system role.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqldatafilepath: {
      type: 'Optional[String]',
      desc: 'Specifies an alternate location to create the database .mdb file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxyname: {
      type: 'Optional[String]',
      desc: 'Specifies the FQDN of the proxy server that the service connection point uses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxyport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies the port number to use for the proxy port.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_clientsusepkicertificate: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether clients will use a client PKI certificate to communicate with site system roles.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_distributionpointinstalliis: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to install the IIS features when installing the Distribution Point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sdkserver: {
      type: 'String',
      desc: 'Specifies the FQDN for the server that will host the SMS Provider.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_action: {
      type: "Enum['InstallCAS', 'installcas', 'InstallPrimarySite', 'installprimarysite']",
      desc: 'Specifies whether to install a CAS or Primary.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasename: {
      type: 'String',
      desc: 'Specifies the name of the SQL Server database to create, or the SQL Server database to use, when setup installs the CAS database.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_prerequisitepath: {
      type: 'String',
      desc: 'Specifies the path to the setup prerequisite files.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_waitforcastimeout: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies the maximum timeout value in minutes for a primary site to connect to the CAS.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_distributionpoint: {
      type: 'Optional[String]',
      desc: 'Specifies the FQDN of the server that will host the distribution point site system role.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_prerequisitecomp: {
      type: 'Boolean',
      desc: 'Specifies whether setup prerequisite files have already been downloaded.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_addserverlanguages: {
      type: "Optional[Enum['DEU', 'deu', 'FRA', 'fra', 'RUS', 'rus', 'CHS', 'chs', 'JPN', 'jpn', 'CHT', 'cht', 'CSY', 'csy', 'ESN', 'esn', 'HUN', 'hun', 'ITA', 'ita', 'KOR', 'kor', 'NLD', 'nld', 'PLK', 'plk', 'PTB', 'ptb', 'PTG', 'ptg', 'SVE', 'sve', 'TRK', 'trk', 'ZHH', 'zhh']]",
      desc: 'Specifies the server languages that will be available for the Configuration Manager console, reports, and Configuration Manager objects.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_casretryinterval: {
      type: 'Optional[String]',
      desc: 'Specifies the retry interval in minutes to attempt a connection to the CAS after the connection fails.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlssbport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies the SQL Server Service Broker (SSB) port that SQL Server uses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_inifilepath: {
      type: 'String',
      desc: 'Specifies the path of the ini file.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_smsinstalldir: {
      type: 'String',
      desc: 'Specifies the installation folder for the Configuration Manager program files.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_adminconsole: {
      type: 'Boolean',
      desc: 'Specifies whether to install the Configuration Manager console.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_cloudconnectorserver: {
      type: 'Optional[String]',
      desc: 'Specifies the FQDN of the server that will host the service connection point site system role.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitename: {
      type: 'String',
      desc: 'Specifies the name for this site.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_distributionpointprotocol: {
      type: "Optional[Enum['HTTPS', 'https', 'HTTP', 'http']]",
      desc: 'Specifies the protocol to use for the distribution point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_cdlatest: {
      type: 'Optional[Boolean]',
      desc: "This value informs setup that you're using media from CD.Latest.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_managementpoint: {
      type: 'Optional[String]',
      desc: 'Specifies the FQDN of the server that will host the management point site system role.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqllogfilepath: {
      type: 'Optional[String]',
      desc: 'Specifies an alternate location to create the database .ldf file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_managementpointprotocol: {
      type: "Optional[Enum['HTTPS', 'https', 'HTTP', 'http']]",
      desc: 'Specifies the protocol to use for the management point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlservername: {
      type: 'String',
      desc: "Specifies the name of the server or clustered instance that's running SQL Server to host the site database.",

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_saactive: {
      type: 'Optional[Boolean]',
      desc: 'Specify if you have active Software Assurance.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_currentbranch: {
      type: 'Optional[Boolean]',
      desc: 'Specify whether to use Configuration Manager current branch or long-term servicing branch (LTSB).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_cloudconnector: {
      type: 'Boolean',
      desc: 'Specifies whether to install a service connection point at this site.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_inifilename: {
      type: 'String',
      desc: 'Specifies the ini file name.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_deleteclientlanguages: {
      type: "Optional[Enum['DEU', 'deu', 'FRA', 'fra', 'RUS', 'rus', 'CHS', 'chs', 'JPN', 'jpn', 'CHT', 'cht', 'CSY', 'csy', 'ESN', 'esn', 'HUN', 'hun', 'ITA', 'ita', 'KOR', 'kor', 'NLD', 'nld', 'PLK', 'plk', 'PTB', 'ptb', 'PTG', 'ptg', 'SVE', 'sve', 'TRK', 'trk', 'ZHH', 'zhh']]",
      desc: "Modifies a site after it's installed. Specifies the languages to remove, and which will no longer be available to client computers.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_deleteserverlanguages: {
      type: "Optional[Enum['DEU', 'deu', 'FRA', 'fra', 'RUS', 'rus', 'CHS', 'chs', 'JPN', 'jpn', 'CHT', 'cht', 'CSY', 'csy', 'ESN', 'esn', 'HUN', 'hun', 'ITA', 'ita', 'KOR', 'kor', 'NLD', 'nld', 'PLK', 'plk', 'PTB', 'ptb', 'PTG', 'ptg', 'SVE', 'sve', 'TRK', 'trk', 'ZHH', 'zhh']]",
      desc: "Modifies a site after it's installed. Specifies the languages to remove, and which will no longer be available for the Configuration Manager console, reports, and Configuration Manager objects.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ccarsiteserver: {
      type: 'Optional[String]',
      desc: 'Specifies the CAS that a primary site attaches to when it joins the Configuration Manager hierarchy',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies three alphanumeric characters that uniquely identify the site in your hierarchy.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_addclientlanguages: {
      type: "Optional[Enum['DEU', 'deu', 'FRA', 'fra', 'RUS', 'rus', 'CHS', 'chs', 'JPN', 'jpn', 'CHT', 'cht', 'CSY', 'csy', 'ESN', 'esn', 'HUN', 'hun', 'ITA', 'ita', 'KOR', 'kor', 'NLD', 'nld', 'PLK', 'plk', 'PTB', 'ptb', 'PTG', 'ptg', 'SVE', 'sve', 'TRK', 'trk', 'ZHH', 'zhh']]",
      desc: 'Specifies the languages that will be available to client computers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mobiledevicelanguage: {
      type: 'Boolean',
      desc: 'Specifies whether the mobile device client languages are installed.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_useproxy: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the service connection point uses a proxy server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_productid: {
      type: 'String',
      desc: 'Specifies the Configuration Manager installation product key, including the dashes.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
