require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmmaintenancewindows',
  dscmeta_resource_friendly_name: 'CMMaintenanceWindows',
  dscmeta_resource_name: 'DSC_CMMaintenanceWindows',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMMaintenanceWindows resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_hourduration: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the duration for the maintenance window in hours, max value 23.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Provides the description of the maintenance window.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_start: {
      type: 'Optional[String]',
      desc: 'Specifies the start date and start time for the maintenance window Month/Day/Year, example 1/1/2020 02:00.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies the name for the maintenance window.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_servicewindowstype: {
      type: "Optional[Enum['Any', 'any', 'SoftwareUpdatesOnly', 'softwareupdatesonly', 'TaskSequencesOnly', 'tasksequencesonly']]",
      desc: 'Specifies what the maintenance window will apply to.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dayofmonth: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the day number for MonthlyByDay schedules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_monthlyweekorder: {
      type: "Optional[Enum['First', 'first', 'Second', 'second', 'Third', 'third', 'Fourth', 'fourth', 'Last', 'last']]",
      desc: 'Specifies week order for MonthlyByWeek schedule type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_dayofweek: {
      type: "Optional[Enum['Sunday', 'sunday', 'Monday', 'monday', 'Tuesday', 'tuesday', 'Wednesday', 'wednesday', 'Thursday', 'thursday', 'Friday', 'friday', 'Saturday', 'saturday']]",
      desc: 'Specifies the day of week name for MonthlyByWeek and Weekly schedules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scheduletype: {
      type: "Optional[Enum['MonthlyByDay', 'monthlybyday', 'MonthlyByWeek', 'monthlybyweek', 'Weekly', 'weekly', 'Days', 'days', 'None', 'none']]",
      desc: 'Specifies the schedule type for the maintenance window.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the maintenance window is present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_collectionstatus: {
      type: 'Optional[String]',
      desc: 'Specifies if the collection applying the maintenance window to exists.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_isenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the maintenance window is enabled, default value is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_collectionname: {
      type: 'String',
      desc: 'Specifies the collection name for the maintenance window.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recurinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how often the ScheduleType is run.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_minuteduration: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the duration for the maintenance window in minutes, max value 59.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
