require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmmanagementpoint',
  dscmeta_resource_friendly_name: 'CMManagementPoint',
  dscmeta_resource_name: 'DSC_CMManagementPoint',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMManagementPoint resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_sqlserverinstancename: {
      type: 'Optional[String]',
      desc: 'Specifies the name of the SQL Server instance that clients use to communicate with the site system.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_username: {
      type: 'Optional[String]',
      desc: 'Specifies a domain user account that the management point uses to access site information.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablessl: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to enable SSL (HTTPS) traffic to the management point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_generatealert: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the management point generates health alerts.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_siteservername: {
      type: 'String',
      desc: 'Specifies the SiteServer to install the role on.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the management point is present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasename: {
      type: 'Optional[String]',
      desc: 'Specifies the name of the site database
eplica that the management point uses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usecomputeraccount: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that the management point uses its own computer account.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_usesitedatabase: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the management point queries a site database.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sqlserverfqdn: {
      type: 'Optional[String]',
      desc: 'Specifies the SQL server FQDN if using a SQL replica.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clientconnectiontype: {
      type: "Optional[Enum['Internet', 'internet', 'Intranet', 'intranet', 'InternetAndIntranet', 'internetandintranet']]",
      desc: 'Specifies the type of the client connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablecloudgateway: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if a cloud gateway is to be used for the management point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
