require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmpulldistributionpoint',
  dscmeta_resource_friendly_name: 'CMPullDistributionPoint',
  dscmeta_resource_name: 'DSC_CMPullDistributionPoint',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMPullDistributionPoint resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_dpstatus: {
      type: 'Optional[String]',
      desc: 'Specifies if the DP role is installed.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_siteservername: {
      type: 'String',
      desc: 'Specifies the SiteServer to configure the Pull Distribution Point.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcedistributionpoint: {
      type: 'Optional[Array[Struct[{
              sourcedp => String,
              dprank => Integer[0, 4294967295],
            }]]]',
      desc: 'Specifies the desired source distribution points and the DP ranking.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'DSC_CMPullDistributionPointSourceDP[]',
      mof_is_embedded: true,
    },
    dsc_enablepulldp: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if EnablePullDP is to be set to enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
