require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmpxedistributionpoint',
  dscmeta_resource_friendly_name: 'CMPxeDistributionPoint',
  dscmeta_resource_name: 'DSC_CMPxeDistributionPoint',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMPxeDistributionPoint resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_pxeserverresponsedelaysec: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies, in seconds, how long the distribution point delays before it responds to computer requests.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_siteservername: {
      type: 'String',
      desc: 'Specifies the SiteServer to configure the Distribution Point for PXE.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dpstatus: {
      type: 'Optional[String]',
      desc: 'Specifies if the DP role is installed.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ismulticast: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if multicast is enabled.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_pxepassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies, as a secure string, the PXE password.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableunknowncomputersupport: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether support for unknown computers is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablepxe: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether PXE is enabled on the distribution point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowpxeresponse: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the distribution point can respond to PXE requests.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablenonwdspxe: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to enable PXE responder without Windows Deployment Services.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_userdeviceaffinity: {
      type: "Optional[Enum['DoNotUse', 'donotuse', 'AllowWithManualApproval', 'allowwithmanualapproval', 'AllowWithAutomaticApproval', 'allowwithautomaticapproval']]",
      desc: 'Specifies how you want the distribution point to associate users with their devices for PXE deployments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
