require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmsiteconfiguration',
  dscmeta_resource_friendly_name: 'CMSiteConfiguration',
  dscmeta_resource_name: 'DSC_CMSiteConfiguration',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMSiteConfiguration resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_useencryption: {
      type: 'Optional[Boolean]',
      desc: 'Specifies to use 3DES to encrypt the client inventory data and state messages that are sent to the management point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sendingwakeuppackettransmissiondelaymins: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of minutes to delay between wake up retries.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_clientcheckcertificaterevocationlistforsitesystem: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether clients check the Certificate Revocation List (CRL) for site systems.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_requiresha256: {
      type: 'Optional[Boolean]',
      desc: "Specifies if the clients sign data and communicate with site systems by using HTTP, this option requires the clients to use SHA-256 to sign the data. This option applies to clients that don't use PKI certificates.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sendingwakeuppackettransmissionoffsetmins: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies when wake up packets should be sent prior to a scheduled activity.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enablelowfreespacealert: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if an alert is created when the free disk space on the site database server is low.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maximumconcurrentsendingforpersite: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of simultaneous communications to any single site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_retrynumberforconcurrentsending: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of times to retry a failed communication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maximumconcurrentsendingforallsite: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of simultaneous communications to all sites.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_usesmsgeneratedcert: {
      type: 'Optional[Boolean]',
      desc: 'Use this parameter to enable or disable the site property to Use Configuration Manager-generated certificates for HTTP site systems.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_concurrentsendingdelaybeforeretryingmins: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of minutes to delay before it retries.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_clientcertificateselectioncriteriavalue: {
      type: 'Optional[String]',
      desc: 'Specifies a value for the ClientCertificateSelectionCriteriaType parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enablewakeonlan: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether to send Wake On LAN packets for scheduled activities such as deployments of software updates.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clientcertificatecustomstorename: {
      type: 'Optional[String]',
      desc: "Specifies the store name where the client certificate is located in the Computer store when you don't use the default store of Personal.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitetype: {
      type: 'Optional[String]',
      desc: 'Specifies the site type, CAS or Primary',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_comment: {
      type: 'Optional[String]',
      desc: 'Specifies the site comment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sendingwakeuppacketbeforepausingwaitsec: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of seconds to wait between sending wake up packets to a target computer.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_threadnumberofsendingwakeuppacket: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of threads to use when sending wake up packets.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_freespacethresholdcriticalgb: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies disk space critical alert when the free disk space on the site database server falls below the specified threshold.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maximumnumberofsendingwakeuppacketbeforepausing: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of wake up packets transmitted by this site server before pausing.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_freespacethresholdwarninggb: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies disk space warning alert when the free disk space on the site database server falls below the specified threshold.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_clientcertificateselectioncriteriatype: {
      type: "Optional[Enum['ClientAuthentication', 'clientauthentication', 'CertificateSubjectContainsString', 'certificatesubjectcontainsstring', 'CertificateSubjectOrSanIncludesAttributes', 'certificatesubjectorsanincludesattributes']]",
      desc: 'Specifies the criteria type to match in a client certificate when more than one certificate is available.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_requiresigning: {
      type: 'Optional[Boolean]',
      desc: 'This option requires that clients sign data when they send to management points.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_retrynumberofsendingwakeuppackettransmission: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of times a wake up packet is sent to a target computer.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_sitesystemcollectionbehavior: {
      type: "Optional[Enum['Warn', 'warn', 'Block', 'block']]",
      desc: 'Specifies the behavior to take when the selected collection includes computers that host site systems roles.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wakeonlantransmissionmethodtype: {
      type: "Optional[Enum['Unicast', 'unicast', 'SubnetDirectedBroadcasts', 'subnetdirectedbroadcasts']]",
      desc: 'Specifies the type of transmission method to use for Wake On LAN transmissions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_takeactionformultiplecertificatematchcriteria: {
      type: "Optional[Enum['FailSelectionAndSendErrorMessage', 'failselectionandsenderrormessage', 'SelectCertificateWithLongestValidityPeriod', 'selectcertificatewithlongestvalidityperiod']]",
      desc: 'Specifies the action to take if multiple certificates match criteria.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usepkiclientcertificate: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether to use a PKI client certificate for client authentication when available.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_thresholdofselectcollectionmax: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies select collection window always hides collections that have more members than this maximum value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_clientcomputercommunicationtype: {
      type: "Optional[Enum['HttpsOnly', 'httpsonly', 'HttpsOrHttp', 'httpsorhttp']]",
      desc: 'Specifies the communication method for the site systems that use IIS. To use HTTPS, the servers need a valid PKI web server certificate for server authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_thresholdofselectcollectionbydefault: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies select collection window hides collections with membership that exceeds this value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
