require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmsitesystemserver',
  dscmeta_resource_friendly_name: 'CMSiteSystemServer',
  dscmeta_resource_name: 'DSC_CMSiteSystemServer',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMSiteSystemServer resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_proxyaccessaccount: {
      type: 'Optional[String]',
      desc: 'Specifies the credentials to use to authenticate with the proxy server. Do not use user principal name UPN format.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_rolecount: {
      type: 'Optional[String]',
      desc: 'Specifies the count of roles on the site system server.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitesystemserver: {
      type: 'String',
      desc: 'Specifies the name of the site system server.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enableproxy: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether to enable a proxy server to use when the server synchronizes information from the Internet.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the site system server is to be present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxyservername: {
      type: 'Optional[String]',
      desc: 'Specifies the name of a proxy server. Use a fully qualified domain name FQDN, short name, or IPv4/IPv6 address.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxyserverport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the proxy server port number to use when connecting to the Internet.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_fdmoperation: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the site system server is required to initiate connections to this site system.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_usesiteserveraccount: {
      type: 'Optional[Boolean]',
      desc: "Indicates that the install uses the site server's computer account to install the site system.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_publicfqdn: {
      type: 'Optional[String]',
      desc: 'Specifies the public FQDN of the site server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_accountname: {
      type: 'Optional[String]',
      desc: 'Specifies the account name for installing the site system.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
