require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmsoftwaredistributioncomponent',
  dscmeta_resource_friendly_name: 'CMSoftwareDistributionComponent',
  dscmeta_resource_name: 'DSC_CMSoftwareDistributionComponent',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMSoftwareDistributionComponent resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_retrycount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the retry count for a package distribution.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_multicastdelaybeforeretryingmins: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the retry delay, in minutes, for a failed multicast distribution.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_accessaccounts: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of accounts to exactly match for Network Access list with software distribution.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_clientcomputeraccount: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the computer account should be used instead of Network Access account.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_accessaccountstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of accounts to exclude from the Network Access account list.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_delaybeforeretryingmins: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the retry delay, in minutes, for a failed package distribution.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maximumthreadcountperpackage: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies a maximum thread count per package for concurrent distribution.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_multicastretrycount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the retry count for a multicast distribution.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_accessaccountstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of accounts to add to the Network Access account list.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maximumpackagecount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies a maximum number of packages for concurrent distribution.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
