require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmsoftwareupdatepoint',
  dscmeta_resource_friendly_name: 'CMSoftwareUpdatePoint',
  dscmeta_resource_name: 'DSC_CMSoftwareUpdatePoint',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMSoftwareUpdatePoint resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_wsusaccessaccount: {
      type: 'Optional[String]',
      desc: 'Specifies an account used to connect to the Wsus server. When not used, specify the AnonymousWsusAccess parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_useproxyforautodeploymentrule: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether an auto deployment rule can use a proxy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_anonymouswsusaccess: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that the software update point allows anonymous access. Mutually exclusive with WsusAccessAccount.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clientconnectiontype: {
      type: "Optional[Enum['Internet', 'internet', 'Intranet', 'intranet', 'InternetAndIntranet', 'internetandintranet']]",
      desc: 'Specifies the type of the client connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_useproxy: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a software update point uses the proxy configured for the site system server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_wsusiissslport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies a port to use for secured access to the Wsus server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies whether the software update point is present or absent.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wsusssl: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the software update point uses SSL to connect to the Wsus server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_siteservername: {
      type: 'String',
      desc: 'Specifies the Site Server to install or configure the role on.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wsusiisport: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies a port to use for unsecured access to the Wsus server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enablecloudgateway: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if a cloud gateway is to be used for the software update point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
