require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmsoftwareupdatepointcomponent',
  dscmeta_resource_friendly_name: 'CMSoftwareUpdatePointComponent',
  dscmeta_resource_name: 'DSC_CMSoftwareUpdatePointComponent',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMSoftwareUpdatePointComponent resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_upstreamsourcelocation: {
      type: 'Optional[String]',
      desc: 'Specifies an upstream data location as a URL.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablesyncfailurealert: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether Configuration Manager creates an alert when synchronization fails on a site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_reportingevent: {
      type: "Optional[Enum['CreateAllWsusReportingEvents', 'createallwsusreportingevents', 'CreateOnlyWsusStatusReportingEvents', 'createonlywsusstatusreportingevents', 'DoNotCreateWsusReportingEvents', 'donotcreatewsusreportingevents']]",
      desc: 'Specifies whether to create event messages for WSUS reporting for status reporting events or for all reporting events.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_languagesummarydetailstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of languages to exclude from the languages supported for software updates summary details at the specified site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_waitmonth: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how long, in months, to wait before a software update expires after another update supersedes it.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_availablecats: {
      type: 'Optional[Array[String]]',
      desc: 'Identifies software update categories and products at the specified site.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_scheduletype: {
      type: "Optional[Enum['MonthlyByDay', 'monthlybyday', 'MonthlyByWeek', 'monthlybyweek', 'Weekly', 'weekly', 'Days', 'days', 'Hours', 'hours']]",
      desc: 'Specifies the schedule type for the synchronization schedule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_languageupdatefilestoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of languages to include in the languages supported for software updates at the specified site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_start: {
      type: 'Optional[String]',
      desc: 'Specifies the start date and start time for the synchronization schedule Month/Day/Year, example 1/1/2020 02:00.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_languagesummarydetails: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of languages desired for the languages supported for software updates summary details at the specified site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_childsite: {
      type: 'Optional[String]',
      desc: 'Identifies whether the specified site is a child site or top level site.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_contentfileoption: {
      type: "Optional[Enum['FullFilesOnly', 'fullfilesonly', 'ExpressForWindows10Only', 'expressforwindows10only']]",
      desc: 'Specifies whether express updates will be downloaded for Windows 10.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_synchronizeaction: {
      type: "Optional[Enum['SynchronizeFromMicrosoftUpdate', 'synchronizefrommicrosoftupdate', 'SynchronizeFromAnUpstreamDataSourceLocation', 'synchronizefromanupstreamdatasourcelocation', 'DoNotSynchronizeFromMicrosoftUpdateOrUpstreamDataSource', 'donotsynchronizefrommicrosoftupdateorupstreamdatasource']]",
      desc: 'Specifies a source for synchronization for this software update point.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_waitmonthforfeature: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how long, in months, to wait before a feature update expires after another update supersedes it.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_productstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of products to include in software updates to synchronize.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_recurinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how often the ScheduleType is run.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_languagesummarydetailstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of languages to include in the languages supported for software updates summary details at the specified site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_monthlyweekorder: {
      type: "Optional[Enum['First', 'first', 'Second', 'second', 'Third', 'third', 'Fourth', 'fourth', 'Last', 'last']]",
      desc: 'Specifies week order for MonthlyByWeek schedule type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_immediatelyexpiresupersedenceforfeature: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a feature update expires immediately after another update supersedes it or after a specified period of time.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_dayofmonth: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the day number for MonthlyByDay schedules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_languageupdatefiles: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of languages desired for the languages supported for software updates at the specified site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enablemanualcertmanagement: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether manual management of the WSUS signing certificate is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_featureupdatemaxruntimemins: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum runtime, in minutes, for windows feature updates.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_languageupdatefilestoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of languages to exclude from the languages supported for software updates at the specified site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enablecallwsuscleanupwizard: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to decline expired updates in WSUS according to superscedence rules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_updateclassifications: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of software update classifications desired for the classifications supported for software updates at this site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_products: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of products desired for software updates to synchronize.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_productstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of products to exclude from software updates to synchronize.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enablethirdpartyupdates: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether third-party updates are enabled on the Software Update Point Component.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_dayofweek: {
      type: "Optional[Enum['Sunday', 'sunday', 'Monday', 'monday', 'Tuesday', 'tuesday', 'Wednesday', 'wednesday', 'Thursday', 'thursday', 'Friday', 'friday', 'Saturday', 'saturday']]",
      desc: 'Specifies the day of week name for MonthlyByWeek and Weekly schedules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_nonfeatureupdatemaxruntimemins: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum runtime, in minutes, for Office 365 updates and windows non-feature updates.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_updateclassificationstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of software update classifications to include in the classifications supported for software updates at this site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_defaultwsusserver: {
      type: 'Optional[String]',
      desc: 'Specifies the default WSUS server that the software update point is pointed to.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_immediatelyexpiresupersedence: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a software update expires immediately after another update supersedes it or after a specified period of time.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_updateclassificationstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of software update classifications to exclude from the classifications supported for software updates at this site.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enablesynchronization: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether this site automatically synchronizes updates according to a schedule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
