require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmstatusreportingcomponent',
  dscmeta_resource_friendly_name: 'CMStatusReportingComponent',
  dscmeta_resource_name: 'DSC_CMStatusReportingComponent',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMStatusReportingComponent resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_serverreportfailurechecked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a server report failure is checked.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clientlogfailurechecked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a client log failure is checked.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serverreporttype: {
      type: "Optional[Enum['AllMilestones', 'allmilestones', 'AllMilestonesAndAllDetails', 'allmilestonesandalldetails', 'ErrorAndWarningMilestones', 'errorandwarningmilestones', 'ErrorMilestones', 'errormilestones']]",
      desc: 'Specifies a server report type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serverlogtype: {
      type: "Optional[Enum['AllMilestones', 'allmilestones', 'AllMilestonesAndAllDetails', 'allmilestonesandalldetails', 'ErrorAndWarningMilestones', 'errorandwarningmilestones', 'ErrorMilestones', 'errormilestones']]",
      desc: 'Specifies a server log type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_serverlogchecked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a server log is checked.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_serverlogfailurechecked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a server log failure is checked.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_serverreportchecked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a server report is checked.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clientreportchecked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a client report is checked.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clientlogchecked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a client log is checked.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clientreportfailurechecked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether a client failure is checked.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_clientlogtype: {
      type: "Optional[Enum['AllMilestones', 'allmilestones', 'AllMilestonesAndAllDetails', 'allmilestonesandalldetails', 'ErrorAndWarningMilestones', 'errorandwarningmilestones', 'ErrorMilestones', 'errormilestones']]",
      desc: 'Specifies a client log type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clientreporttype: {
      type: "Optional[Enum['AllMilestones', 'allmilestones', 'AllMilestonesAndAllDetails', 'allmilestonesandalldetails', 'ErrorAndWarningMilestones', 'errorandwarningmilestones', 'ErrorMilestones', 'errormilestones']]",
      desc: 'Specifies a client report type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
