require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmsystemdiscovery',
  dscmeta_resource_friendly_name: 'CMSystemDiscovery',
  dscmeta_resource_name: 'DSC_CMSystemDiscovery',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '4.0.0',
  docs: 'The DSC CMSystemDiscovery resource type.
         Automatically generated from version 4.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enablefilteringexpiredpassword: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether Configuration Manager discovers only computers that have updated their computer account password within a specified number of days.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scheduleinterval: {
      type: "Optional[Enum['None', 'none', 'Days', 'days', 'Hours', 'hours', 'Minutes', 'minutes']]",
      desc: 'Specifies the time when the scheduled event recurs.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabledeltadiscovery: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether Configuration Manager discovers resources created or modified in AD DS since the last discovery cycle.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_schedulecount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how often the recur interval is run.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_adcontainerstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names of Active Directory containers to exclude to the discovery.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_adcontainerstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names of Active Directory containers to add to the discovery.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_deltadiscoverymins: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of minutes for the delta discovery.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_timesincelastlogondays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specify the number of days for EnableFilteringExpiredLogon.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_adcontainers: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies an array of names of Active Directory containers to match to the discovery.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enablefilteringexpiredlogon: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether Configuration Manager discovers only computers that have logged onto a domain within a specified number of days.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Boolean',
      desc: 'Specifies the enablement of the system discovery method.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_timesincelastpasswordupdatedays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specify the number of days for EnableFilteringExpiredPassword.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
